from onegov.people.models import Person


class PersonCollection(object):

    def __init__(self, session):
        self.session = session

    def query(self):
        return self.session.query(Person)

    def add(self, first_name, last_name, **optional):
        person = Person(first_name=first_name, last_name=last_name, **optional)

        self.session.add(person)
        self.session.flush()

        return person

    def delete(self, person):
        self.session.delete(person)
        self.session.flush()

    def by_id(self, id):
        return self.query().filter(Person.id == id).first()



# -*- coding: utf-8 -*-

from onegov.core.orm import Base
from onegov.core.orm.mixins import TimestampMixin
from onegov.core.orm.types import UUID
from sqlalchemy import Column, Text
from uuid import uuid4


class Person(Base, TimestampMixin):

    __tablename__ = 'people'

    @property
    def title(self):
        if self.salutation:
            parts = self.salutation, self.first_name, self.last_name
        else:
            parts = self.first_name, self.last_name

        return u" ".join(parts)

    #: the unique id, part of the url
    id = Column(UUID, primary_key=True, default=uuid4)

    salutation = Column(Text, nullable=True)

    first_name = Column(Text, nullable=False)

    last_name = Column(Text, nullable=False)

    picture_url = Column(Text, nullable=True)

    email = Column(Text, nullable=True)

    phone = Column(Text, nullable=True)

    website = Column(Text, nullable=True)

    address = Column(Text, nullable=True)



""" Contains upgrade tasks that are executed when the application is being
upgraded on the server. See :class:`onegov.core.upgrade.upgrade_task`.

"""
from onegov.core.upgrade import upgrade_task


@upgrade_task('Rename academic_title to salutation')
def rename_academic_title_to_salutation(context):

    context.operations.alter_column(
        'people', 'academic_title', new_column_name='salutation')
